@@ -4,7 +4,7 @@
 from __future__ import unicode_literals
 import copy
 import inspect
-from django.db import transaction
+from django.db import router
 from django.db.models import Model, Manager, get_model
 from django.db.models.query import RawQuerySet
 from django.utils import six
@@ -34,6 +34,7 @@ class MoQuerySet(object):
         self.extra_fields = extra_fields
         self._db = using
         self._rawqueryset = None
+        self._for_write = False
         self._params = {
             'offset': 0,
             'limit': None,
@@ -77,6 +78,12 @@ class MoQuerySet(object):
         else:
             return list(self)[k]
 
+    @property
+    def db(self):
+        if self._for_write:
+            return self._db or router.db_for_write(self.model)
+        return self._db or router.db_for_read(self.model)
+
     def _clone(self):
         clone = MoQuerySet(
             model=self.model,
@@ -89,7 +96,7 @@ class MoQuerySet(object):
 
     def _get_select_query(self, fields=None):
         """The raw SQL that will be used to resolve the queryset."""
-        handler = get_engine_handler(self._db)
+        handler = get_engine_handler(self.db)
 
         with handler.patch():
             params = copy.deepcopy(self._params)
@@ -109,7 +116,7 @@ class MoQuerySet(object):
             #   use a "*" to indicate all fields;
             # If the query has aggregation (GROUP BY), however, we will need to
             #   choose a value to display for each field (especially pk because
-            #   it is needed by Django). Since ccessing those fields doesn't
+            #   it is needed by Django). Since accessing those fields doesn't
             #   really make sense anyway, We arbitrarily use MIN.
             table_name = alias or table
 
@@ -145,7 +152,8 @@ class MoQuerySet(object):
         # Try to keep things simple by resolving a direct DELETE ... WHERE ...
         # query. If that proves impossible, fallback to the naive DELETE ...
         # WHERE <pk> IN (SELECT ...) solution.
-        handler = get_engine_handler(self._db)
+        self._for_write = True
+        handler = get_engine_handler(self.db)
         table = self.model._meta.db_table
 
         params = copy.deepcopy(self._params)
@@ -163,7 +171,6 @@ class MoQuerySet(object):
         # Execute the query
         cursor = handler.cursor()
         cursor.execute(query)
-        transaction.commit_unless_managed()
         return cursor.rowcount
 
     def resolve(self):
